@@ -26,7 +26,7 @@ class RBPurposeQuickPlugin : public QQmlExtensionPlugin
 	Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
 public:
-    void registerTypes(const char* uri) Q_DECL_OVERRIDE;
+    void registerTypes(const char* uri) override;
 };
 
 #endif // PURPOSEQUICKPLUGIN_H
